@@ -130,26 +130,21 @@
 #' expressed as fractional years, meaning this will work extremely poorly
 #' when using e.g. day-level time scales (such as \code{Date} variables). 
 #' Set the extrapolation breaks manually in such cases.
-#' 
+#' @md
 #' @return 
-#' Returns a \code{data.frame} or \code{data.table} (depending on 
+#' Returns a \code{data.frame} or \code{data.table} (depending on
 #' \code{getOptions("popEpi.datatable")}; see \code{?popEpi}) containing the
 #' following columns:
-#' \itemize{
-#'   \item{est}{: The estimated mean survival time}
-#'   \item{exp}{: The computed expected survival time}
-#'   \item{obs}{: Counts of subjects in data}
-#'   \item{YPLL}{: Years of Potential Life Lost, computed as 
-#'   (\code{(exp-est)*obs}) - though your time data may be in e.g. days,
-#'   this column will have the same name regardless.}
-#' }
+#' - `est`: The estimated mean survival time
+#' - `exp`: The computed expected survival time
+#' - `obs`: Counts of subjects in data
+#' - `YPLL`: Years of Potential Life Lost, computed as
+#'   (`(exp - est) * obs`) --- though your time data may be in e.g. days,
+#'   this column will have the same name regardless.
 #' The returned data also has columns named according to the variables
 #' supplied to the right-hand-side of the formula.
-#' 
-#' 
 #' @examples
 #' 
-#' library(survival)
 #' library(Epi)
 #' ## take 500 subjects randomly for demonstration
 #' data(sire)
@@ -186,7 +181,7 @@
 #' sm1 <- survmean(FUT ~ 1,
 #'                 pophaz = pm, data = x, weights = NULL,
 #'                 breaks = BL)             
-#' \dontrun{
+#' \donttest{
 #' ## mean survival by group                 
 #' sm2 <- survmean(FUT ~ group,
 #'                 pophaz = pm, data = x, weights = NULL,
@@ -205,7 +200,7 @@
 #' ## solid lines are observed + extrapolated survivals;
 #' ## dashed lines are expected survivals
 #' plot(sm1)
-#' \dontrun{
+#' \donttest{
 #' ## plotting object with both stratification and standardization
 #' ## plots curves for each strata-std.group combination
 #' plot(sm3)
@@ -265,10 +260,6 @@ survmean <- function(formula, data, adjust = NULL, weights = NULL,
   
   surv.method <- match.arg(surv.method, c("hazard", "lifetable"))
   
-  if(!requireNamespace("survival")) {
-    stop("Need package 'survival' to proceed")
-  }
-  
   ## appease R CMD CHECK (due to using vars in DT[] only)
   r.e2 <- last.p.e2 <- surv <- survmean_type <- est <- Tstart <- Tstop <- 
     lex.id <- surv.int <- delta <- surv.exp <- obs <- NULL
