@@ -1,21 +1,21 @@
-context("test rpcurve vs. survtab congruence")
+testthat::context("test rpcurve vs. survtab congruence")
 
-test_that("rpcurve and survtab e2 are approximately congruent", {
-  skip_on_cran()
+testthat::test_that("rpcurve and survtab e2 are approximately congruent", {
+  popEpi:::skip_normally()
   
-  sire2 <- copy(sire)[dg_date < ex_date, ]
-  sire2[, agegr := cut(dg_age, breaks = c(0,45,70,Inf))]
+  sire2 <- popEpi::sire[dg_date < ex_date, ]
+  sire2[, "agegr" := cut(dg_age, breaks = c(0,45,70,Inf))]
   
   fb <- c(0,3/12,6/12,1:8,10)
   x <- lexpand(sire2, birth  = bi_date, entry = dg_date, exit = ex_date,
                status = status %in% 1:2,
                fot=fb,  pophaz=data.table(popEpi::popmort))
-  setDT(x)
-  setattr(x, "class", c("Lexis", "data.table", "data.frame"))
+  data.table::setDT(x)
+  data.table::setattr(x, "class", c("Lexis", "data.table", "data.frame"))
   rp <- relpois(x, formula = lex.Xst %in% 1:2 ~ -1 + FOT+agegr)
   mc <- rpcurve(rp)
   
-  x$pop.haz <- NULL
+  x[, pop.haz := NULL]
   pm <- data.table(popEpi::popmort)
   setnames(pm, c("year", "agegroup"), c("per", "age"))
   w <- as.numeric(table(x$agegr))
@@ -26,14 +26,14 @@ test_that("rpcurve and survtab e2 are approximately congruent", {
   setDT(mc)
   setDT(st)
   
-  expect_equal(st[Tstop %in% fb]$r.e2.as, mc$est, tolerance=0.0136, scale=1L)
+  testthat::expect_equal(st[Tstop %in% fb]$r.e2.as, mc$est, tolerance=0.0136, scale=1L)
   
   ## added old results on 2016-03-19, 
   ## ref = 4feb1ca37489737332cebf33d24550a9951a7630
   old_res <- c(0.9253749, 0.8801775, 0.8123319, 0.7237591, 0.6679470, 
                0.6315218, 0.6035761, 0.5826368, 0.5645760, 0.5519045, 0.5368186)
   
-  expect_equal(old_res, mc$est, tolerance=1e-5, scale=1L)
+  testthat::expect_equal(old_res, mc$est, tolerance=1e-5, scale=1L)
 })
 
 
@@ -45,7 +45,7 @@ test_that("rpcurve and survtab e2 are approximately congruent", {
 # sire2[, agegroup := as.integer(as.integer(ex_date-bi_date)/365.25)]
 # sire2[agegroup > 100, agegroup := 100L]
 # 
-# sire2 <- data.table:::merge.data.table(sire2, popmort, all.x=F, all.y=F, by=c("sex","year","agegroup"))
+# sire2 <- data.table:::merge.data.table(sire2, popmort, all.x=FALSE, all.y=FALSE, by=c("sex","year","agegroup"))
 # sire2[lex.Xst == 0, haz := 0] ## not really needed, nothing changes even when it works
 # 
 # ## spline model does not work with bhazard (nothing changes)
